==> openapi_jira_client-3.0.0-py3-none-any.whl: openapi_jira_client/api/filter_sharing/delete_share_permission.py <==
from typing import Any, Dict, List, Optional, Union, cast

import httpx
from attr import asdict

from ...client import AuthenticatedClient, Client
from ...types import UNSET, Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    id: int,
    permission_id: int,
) -> Dict[str, Any]:
    url = "{}/rest/api/3/filter/{id}/permission/{permissionId}".format(
        client.base_url, id=id, permissionId=permission_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[None, None, None]]:
    if response.status_code == 204:
        response_204 = None

        return response_204
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[None, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    id: int,
    permission_id: int,
) -> Response[Union[None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        id=id,
        permission_id=permission_id,
    )

    response = httpx.delete(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    id: int,
    permission_id: int,
) -> Optional[Union[None, None, None]]:
    """Deletes a share permission from a filter.

    **[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter."""

    return sync_detailed(
        client=client,
        id=id,
        permission_id=permission_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    id: int,
    permission_id: int,
) -> Response[Union[None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        id=id,
        permission_id=permission_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    id: int,
    permission_id: int,
) -> Optional[Union[None, None, None]]:
    """Deletes a share permission from a filter.

    **[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter."""

    return (
        await asyncio_detailed(
            client=client,
            id=id,
            permission_id=permission_id,
        )
    ).parsed

==> openapi_jira_client-3.0.1-py3-none-any.whl: openapi_jira_client/api/filter_sharing/delete_share_permission.py <==
from typing import Any, Dict, List, Optional, Union, cast

import httpx
from attr import asdict

from ...client import AuthenticatedClient, Client
from ...types import UNSET, Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    id_: int,
    permission_id: int,
) -> Dict[str, Any]:
    url = "{}/rest/api/3/filter/{id}/permission/{permissionId}".format(
        client.base_url, id=id_, permissionId=permission_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[None, None, None]]:
    if response.status_code == 204:
        response_204 = None

        return response_204
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[None, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    id_: int,
    permission_id: int,
) -> Response[Union[None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        id_=id_,
        permission_id=permission_id,
    )

    response = httpx.delete(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    id_: int,
    permission_id: int,
) -> Optional[Union[None, None, None]]:
    """Deletes a share permission from a filter.

    **[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter."""

    return sync_detailed(
        client=client,
        id_=id_,
        permission_id=permission_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    id_: int,
    permission_id: int,
) -> Response[Union[None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        id_=id_,
        permission_id=permission_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    id_: int,
    permission_id: int,
) -> Optional[Union[None, None, None]]:
    """Deletes a share permission from a filter.

    **[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter."""

    return (
        await asyncio_detailed(
            client=client,
            id_=id_,
            permission_id=permission_id,
        )
    ).parsed
